==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/specalization/observer/prot/BeanD.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.specalization.observer.prot;


import org.apache.webbeans.test.specalization.observer.TestEvent;

import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.event.Observes;
import javax.enterprise.inject.Alternative;
import javax.enterprise.inject.Specializes;

@Specializes
@Alternative
@ApplicationScoped
public class BeanD extends BeanA
{
    private static final long serialVersionUID = 821164664338581947L;

    @Override
    protected void observeTestEvent(@Observes TestEvent testEvent)
    {
        testEvent.addInvocation(getBeanName());
    }

    @Override
    public String getBeanName()
    {
        return super.getBeanName() + ":[alternative]:[specialize]";
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/specalization/observer/prot/BeanD.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.specalization.observer.prot;


import org.apache.webbeans.test.specalization.observer.TestEvent;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.enterprise.event.Observes;
import jakarta.enterprise.inject.Alternative;
import jakarta.enterprise.inject.Specializes;

@Specializes
@Alternative
@ApplicationScoped
public class BeanD extends BeanA
{
    private static final long serialVersionUID = 821164664338581947L;

    @Override
    protected void observeTestEvent(@Observes TestEvent testEvent)
    {
        testEvent.addInvocation(getBeanName());
    }

    @Override
    public String getBeanName()
    {
        return super.getBeanName() + ":[alternative]:[specialize]";
    }
}
